@@ -168,6 +168,7 @@ class Update:
                 "expiration_datetime": row["ExpirationDateTime"],
                 "disabled": row["Disabled"],
                 "lost": row["Lost"],
+                "status": row["Status"],
                 "stolen": row["Stolen"],
             }
             credentials.append(data)
@@ -327,25 +328,16 @@ class Update:
         # create dicts of people by emplid and pid
         for p in people:
             emplid = p["emplid"]
-            # pid = p["person_id"]
-            worker_sub_type = p["worker_sub_type"]
-
             p["company"] = ""
-            # p["disabled"] = p["terminated"]
             if "disabled" in p:
                 del p["disabled"]
-            # p["first_name"] = p["first_name_ascii"]
-            if (len(p["home_institution"]) < 125):
-                p["home_institution"][:125]
-            # p["last_name"] = p["last_name_ascii"]
-            # p["legal_name"] = f"{p['legal_last_name']},{p['legal_first_name']}"
+            if len(p["home_institution"]) > 150:
+                p["home_institution"] = p["home_institution"][:150]
             p["middle_name"] = ""
-            # p["parking"] = "Yes" if p["parking"] else "No"
             p["person_id"] = ""
+            worker_sub_type = p["worker_sub_type"]
             p["personnel_type_name"] = worker_sub_type if worker_sub_type in personnel_type_names else "None"
             p["pid"] = ""
-            # p["status"] = "Terminated" if p["terminated"] else "Active"
-            # p["supervisor_name"] = p["manager_ascii"]
             p["text11"] = ""
             p["text12"] = ""
             p["text13"] = ""
@@ -357,20 +349,6 @@ class Update:
             p["text24"] = ""
             p["text25"] = ""
 
-            # get activation datetime
-            # start_date = p["activation_datetime"]
-            # activation_datetime = "1990-01-01 00:00:01"
-            # if start_date and start_date >= "1990-01-01":
-            #     activation_datetime = f"{start_date} 00:00:01"
-            # p["activation_datetime"] = activation_datetime
-
-            # # get expiration datetime
-            # end_date = p["security_card_end_date"]
-            # expiration_datetime = "2037-12-31 00:00:01"
-            # if end_date:
-            #     expiration_datetime = f"{end_date} 23:59:59"
-            # p["expiration_datetime"] = expiration_datetime
-
             # check for missing personnel types in CCURE
             if worker_sub_type not in personnel_type_names and worker_sub_type not in missing_personnel_types:
                 missing_personnel_types.append(worker_sub_type)
@@ -402,6 +380,12 @@ class Update:
         person_cards = {}
         for oid in self.credentials:
             c = self.credentials[oid]
+            # skip disabled credentials
+            if c["disabled"]:
+                continue
+            # skip temporary credentials:
+            if c["status"] == 2:
+                continue
             pid = c["personnel_id"]
             # skip personnel that weren't matched with workday
             if pid not in people:
@@ -436,8 +420,9 @@ class Update:
                     emplid = p["emplid"]
                     first_name = p["first_name"]
                     last_name = p["last_name"]
+                    personnel_id = c["personnel_id"]
 
-                    print(f"\n{card_id} {first_name} {last_name} [{emplid}]:")
+                    print(f"\n{card_id} {first_name} {last_name} [{personnel_id} - {emplid}]:")
                     print("\n".join(output))
 
         return entries
@@ -595,7 +580,7 @@ class Update:
         # check matched people
         print(f"\nChecking {len(matched)} existing Workday Personnel for updates...")
         personnel_to_update = self.check_matched_people(matched)
-        print(f"Updating {len(personnel_to_update)} Workday Personnel in CCURE.")
+        print(f"\nUpdating {len(personnel_to_update)} Workday Personnel in CCURE.")
 
         # check unmatched people
         # print(f"\fChecking {len(unmatched)} unmatched Workday Personnel...")
@@ -610,7 +595,7 @@ class Update:
         # generate the personnel.csv
         self.write_personnel(personnel_to_update)
 
-        # # check CCURE-only people
+        # check CCURE-only people
         # print(f"\fChecking {len(ccure_people)} CCURE-only Personnel...")
         # category = ""
         # bademplids = []
@@ -633,6 +618,11 @@ class Update:
         #         bademplids.append(p)
 
         # if bademplids:
-        #     print(f"Found {len(bademplids)} CCURE-only records with an EMPLID!")
+        #     print(f"\nFound {len(bademplids)} CCURE-only records with an EMPLID!")
         #     for p in bademplids:
-        #         print(p["emplid"], p["personnel_type_name"])
\ No newline at end of file
+        #         oid = p["id"]
+        #         emplid = p["emplid"]
+        #         first_name = p["first_name"]
+        #         last_name = p["last_name"]
+        #         personnel_type_name = p["personnel_type_name"]
+        #         print(f"  {oid} {first_name} {last_name} - {personnel_type_name} [{emplid}]")
